@@ -38,6 +38,7 @@ Usage:
       [-polymer-name pname] \\
       [-monomer-name mname] \\
       [-sequence sequence.txt] \\
+      [-bond a1 a2] \\
       [-bond btype a1 a2] \\
       [-angle    atype a1 a2 a3 i1 i2 i3] \\
       [-dihedral dtype a1 a2 a3 a4 i1 i2 i3 i4] \\
@@ -91,6 +92,7 @@ class GPSettings(object):
         self.header = ''
         self.name_monomer = 'Monomer'
         self.name_sequence_file = ''
+        self.name_sequence_multi = []
         self.name_polymer = ''
         self.inherits = ''
         self.dir_index_offsets = (-1,1)
@@ -101,6 +103,9 @@ class GPSettings(object):
         self.bonds_type = []
         self.bonds_atoms = []
         self.bonds_index_offsets = []
+        self.bonds_name_notype = []
+        self.bonds_atoms_notype = []
+        self.bonds_index_offsets_notype = []
         self.angles_name = []
         self.angles_type = []
         self.angles_atoms = []
@@ -130,15 +135,26 @@ class GPSettings(object):
                 self.infile_name = argv[i + 1]
                 del(argv[i:i + 2])
             elif argv[i].lower() == '-bond':
-                if i + 3 >= len(argv):
+                if i + 2 >= len(argv):
                     raise InputError(
-                        'Error: The ' + argv[i] + ' flag should be followed by 3 strings.\n')
-                # self.bonds_name.append(argv[i+1])
-                self.bonds_type.append(argv[i + 1])
-                self.bonds_atoms.append((argv[i + 2],
-                                         argv[i + 3]))
-                self.bonds_index_offsets.append((0, 1))
-                del(argv[i:i + 4])
+                        'Error: The ' + argv[i] + ' flag should be followed by at 2 or 3 strings.\n')
+                has_third_arg = True
+                if ((i + 3 >= len(argv)) or (argv[i+3][0:1] == '-')):
+                    has_third_arg = False
+                # Did the user specify the type of the bond?
+                if has_third_arg:
+                    # then the type was specified (put in "Data Bonds")
+                    self.bonds_type.append(argv[i + 1])
+                    self.bonds_atoms.append((argv[i + 2],
+                                             argv[i + 3]))
+                    self.bonds_index_offsets.append((0, 1))
+                    del(argv[i:i + 4])
+                else:
+                    # then the type was not specified (put in "Data Bond List")
+                    self.bonds_atoms_notype.append((argv[i + 1],
+                                                     argv[i + 2]))
+                    self.bonds_index_offsets_notype.append((0, 1))
+                    del(argv[i:i + 3])
             elif argv[i].lower() == '-angle':
                 if i + 7 >= len(argv):
                     raise InputError(
@@ -359,33 +375,8 @@ class GPSettings(object):
             else:
                 i += 1
 
-        if ((len(self.reverse_polymer_directions) != 0) and 
-            (len(self.reverse_polymer_directions) != len(self.cuts) + 1)):
-            raise InputError('Error: The number of entries in the file you supplied to "-polymer-directions"\n'
-                             '       does not equal the number of polymers (which is either 1, or 1 + the\n'
-                             '       number of entries in the file you supplied to "-cuts", if applicable)\n')
 
 
-        for b in range(0, len(self.bonds_type)):
-            if len(self.bonds_type) > 1:
-                self.bonds_name.append('genp_bond' + str(b + 1) + '_')
-            else:
-                self.bonds_name.append('genp_bond_')
-        for b in range(0, len(self.angles_type)):
-            if len(self.angles_type) > 1:
-                self.angles_name.append('genp_angle' + str(b + 1) + '_')
-            else:
-                self.angles_name.append('genp_angle_')
-        for b in range(0, len(self.dihedrals_type)):
-            if len(self.dihedrals_type) > 1:
-                self.dihedrals_name.append('genp_dihedral' + str(b + 1) + '_')
-            else:
-                self.dihedrals_name.append('genp_dihedral_')
-        for b in range(0, len(self.impropers_type)):
-            if len(self.impropers_type) > 1:
-                self.impropers_name.append('genp_improper' + str(b + 1) + '_')
-            else:
-                self.impropers_name.append('genp_improper_')
 
 
 
@@ -445,6 +436,90 @@ class GenPoly(object):
         self.settings.ParseArgs(argv)
 
 
+        # ---- Parsing is finished.  Now load files and cleanup. ----
+
+        if self.settings.infile_name != '':
+            infile = open(self.settings.infile_name, 'r')
+            self.coords_multi = self.ReadCoords(infile)
+            infile.close()
+
+        if ((len(self.settings.reverse_polymer_directions) != 0) and 
+            (len(self.settings.reverse_polymer_directions) !=
+             len(self.cuts) + 1)):
+            raise InputError('Error: The number of entries in the file you supplied to "-polymer-directions"\n'
+                             '       does not equal the number of polymers (which is either 1, or 1 + the\n'
+                             '       number of entries in the file you supplied to "-cuts", if applicable)\n')
+
+
+        for b in range(0, len(self.settings.bonds_type)):
+            if len(self.settings.bonds_type) > 1:
+                self.settings.bonds_name.append('genp_bond' + str(b + 1) + '_')
+            else:
+                self.settings.bonds_name.append('genp_bond_')
+        for b in range(0, len(self.settings.bonds_atoms_notype)):
+            if len(self.settings.bonds_atoms_notype) > 1:
+                self.settings.bonds_name_notype.append('genp_bond_nt' + str(b + 1) + '_')
+            else:
+                self.settings.bonds_name_notype.append('genp_bond_nt')
+        for b in range(0, len(self.settings.angles_type)):
+            if len(self.settings.angles_type) > 1:
+                self.settings.angles_name.append('genp_angle' + str(b + 1) + '_')
+            else:
+                self.settings.angles_name.append('genp_angle_')
+        for b in range(0, len(self.settings.dihedrals_type)):
+            if len(self.settings.dihedrals_type) > 1:
+                self.settings.dihedrals_name.append('genp_dihedral' + str(b + 1) + '_')
+            else:
+                self.settings.dihedrals_name.append('genp_dihedral_')
+        for b in range(0, len(self.settings.impropers_type)):
+            if len(self.settings.impropers_type) > 1:
+                self.settings.impropers_name.append('genp_improper' + str(b + 1) + '_')
+            else:
+                self.settings.impropers_name.append('genp_improper_')
+
+
+
+        # Did the user ask us to read a custom sequence of monomer type names?
+        name_sequence_file = None
+        if isinstance(self.settings.name_sequence_file, str):
+            if self.settings.name_sequence_file != '':
+                name_sequence_file = open(self.settings.name_sequence_file,'r')
+        if name_sequence_file:
+            # Note: This will fill the contents of self.name_sequence_multi
+            self.ReadSequence(name_sequence_file)
+
+        # Did the user specify a file with a list of orientations?
+        orientations_file = None
+        if isinstance(self.settings.orientations_file, str):
+            if self.settings.orientations_file != '':
+                orientations_file = open(self.settings.orientations_file, 'r')
+        else:
+            orientations_file = self.settings.orientations_file
+        if orientations_file:
+            if self.settings.orientations_use_quats:
+                self.orientations_multi = self.ReadCoords(orientations_file, 4)
+            else:
+                self.orientations_multi = self.ReadCoords(orientations_file, 9)
+
+        # Did the user specify a file with a list of helix angles?
+        helix_angles_file = None
+        if isinstance(self.settings.helix_angles_file, str):
+            if self.settings.helix_angles_file != '':
+                helix_angles_file = open(self.settings.helix_angles_file, 'r')
+        else:
+            helix_angles_file = self.settings.helix_angles_file
+        if helix_angles_file:
+            self.helix_angles_multi = self.ReadCoords(self.settings.helix_angles_file, 1)
+            # Because I borrowed the ReadCoords() function to read the file,
+            # each "angle" is ended up being a list containing only one element
+            # (the angle).  Convert this list into the number stored there.
+            for i in range(0, len(self.helix_angles_multi)):
+                for j in range(0, len(self.helix_angles_multi[i])):
+                    assert(len(self.helix_angles_multi[i][j]) == 1)
+                    self.helix_angles_multi[i][j] = self.helix_angles_multi[i][j][0]
+
+
+
 
     def ReadCoords(self, infile, ncolumns=3):
         """
@@ -633,7 +708,7 @@ class GenPoly(object):
 
         """
 
-        # make sure len(genpoly.orientations_multi) == len(genpoly.coords_multi)
+        # make sure len(self.orientations_multi) == len(self.coords_multi)
         if len(self.orientations_multi) == 0:
             self.orientations_multi = [[] for entry in self.coords_multi]
         # make sure len(self.helix_angles_multi) == len(self.coords_multi)
@@ -823,6 +898,35 @@ class GenPoly(object):
             outfile.write("  }  # write(\"Data Bonds\") {...\n\n\n")
 
 
+        assert(len(self.settings.bonds_name_notype) ==
+               len(self.settings.bonds_atoms_notype) ==
+               len(self.settings.bonds_index_offsets_notype))
+
+        if len(self.settings.bonds_atoms_notype) > 0:
+            outfile.write("\n"
+                          "\n"
+                          "  write(\"Data Bond List\") {\n")
+
+        WrapPeriodic.bounds_err = False
+        for i in range(0, N):
+            test = False
+            for b in range(0, len(self.settings.bonds_atoms_notype)):
+                I = i + self.settings.bonds_index_offsets_notype[b][0]
+                J = i + self.settings.bonds_index_offsets_notype[b][1]
+                I = WrapPeriodic.Wrap(I, N)
+                J = WrapPeriodic.Wrap(J, N)
+                if WrapPeriodic.bounds_err:
+                    WrapPeriodic.bounds_err = False
+                    if not self.settings.connect_ends:
+                        continue
+                outfile.write(
+                    "    $bond:" + self.settings.bonds_name_notype[b] + str(i + 1))
+                outfile.write(" $atom:mon[" + str(I) + "]/" + self.settings.bonds_atoms_notype[
+                              b][0] + " $atom:mon[" + str(J) + "]/" + self.settings.bonds_atoms_notype[b][1] + "\n")
+        if len(self.settings.bonds_atoms_notype) > 0:
+            outfile.write("  }  # write(\"Data Bond List\") {...\n\n\n")
+
+
         assert(len(self.settings.angles_name) ==
                len(self.settings.angles_type) ==
                len(self.settings.angles_atoms) ==
@@ -960,8 +1064,8 @@ class GenPoly(object):
 def main():
     try:
         g_program_name = __file__.split('/')[-1]
-        g_version_str = '0.1.7'
-        g_date_str = '2021-6-21'
+        g_version_str = '0.1.10'
+        g_date_str = '2021-12-28'
         sys.stderr.write(g_program_name + ' v' +
                          g_version_str + ' ' + g_date_str + '\n')
         argv = [arg for arg in sys.argv]
@@ -974,61 +1078,34 @@ def main():
                              '\"\n\n' +
                              g_usage_msg)
 
-        if genpoly.settings.infile_name != '':
-            infile = open(genpoly.settings.infile_name, 'r')
-        else:
-            infile = sys.stdin
+        if genpoly.settings.infile_name == '':
+            # If the user did not specify the name of the file where the
+            # coordinates are stored, then the user wants us to read
+            # them from the standard (terminal) input (sys.stdin)
+            genpoly.coords_multi = genpoly.ReadCoords(sys.stdin)
+
         outfile = sys.stdout
 
         # Read the coordinates
-        genpoly.coords_multi = genpoly.ReadCoords(infile)
+        
 
-        # Did the user ask us to read a custom sequence of monomer type names?
-        name_sequence_file = None
-        if isinstance(genpoly.settings.name_sequence_file, str):
-            if genpoly.settings.name_sequence_file != '':
-                name_sequence_file = open(genpoly.settings.name_sequence_file,'r')
-        if name_sequence_file:
-            # Note: This will fill the contents of genpoly.name_sequence_multi
-            genpoly.ReadSequence(name_sequence_file)
-        else:
-            # Otherwise just fill genpoly.name_sequence_multi with
-            #  repeated copies of genpoly.settings.name_monomer
-            #   (...using this ugly two-dimensional list-of-lists comprehension)
+        if genpoly.name_sequence_multi == []:
+            # In that case it means we should assume that each monomer in
+            # the polymer(s) is of the same type.  So we fill the
+            # genpoly.name_sequence_multi array with the same entry. Recall that
+            # variables ending in "_multi" are two-dimensional lists take two
+            # indices [i][j]
+            # The first index [i] specifies the polymer
+            # The second index [j] specifies the monomer within that polymer.
+            # I will use the following ugly list comprehension to create a
+            # two-dimensional list-of-lists whose shape and size is consistent
+            # with the size of the genpoly.coords_multi array.
+            # And I will fill it with "genpoly.settings.name_monomer"
             genpoly.name_sequence_multi = [[genpoly.settings.name_monomer
                                             for j in
                                             range(0, len(genpoly.coords_multi[i]))]
                                            for i in range(0, len(genpoly.coords_multi))]
 
-        # Did the user specify a file with a list of orientations?
-        orientations_file = None
-        if isinstance(genpoly.settings.orientations_file, str):
-            if genpoly.settings.orientations_file != '':
-                orientations_file = open(genpoly.settings.orientations_file, 'r')
-        else:
-            orientations_file = genpoly.settings.orientations_file
-        if orientations_file:
-            if genpoly.settings.orientations_use_quats:
-                genpoly.orientations_multi = genpoly.ReadCoords(orientations_file, 4)
-            else:
-                genpoly.orientations_multi = genpoly.ReadCoords(orientations_file, 9)
-
-        # Did the user specify a file with a list of helix angles?
-        helix_angles_file = None
-        if isinstance(genpoly.settings.helix_angles_file, str):
-            if genpoly.settings.helix_angles_file != '':
-                helix_angles_file = open(genpoly.settings.helix_angles_file, 'r')
-        helix_angles_file = genpoly.settings.helix_angles_file
-        if helix_angles_file:
-            genpoly.helix_angles_multi = genpoly.ReadCoords(genpoly.settings.helix_angles_file, 1)
-            # Because I borrowed the ReadCoords() function to read the file,
-            # each "angle" is ended up being a list containing only one element
-            # (the angle).  Convert this list into the number stored there.
-            for i in range(0, len(genpoly.helix_angles_multi)):
-                for j in range(0, len(genpoly.helix_angles_multi[i])):
-                    assert(len(genpoly.helix_angles_multi[i][j]) == 1)
-                    genpoly.helix_angles_multi[i][j] = genpoly.helix_angles_multi[i][j][0]
-
         # Now, check for polymer and sequence length inconsistencies:
         if (len(genpoly.coords_multi) != len(genpoly.name_sequence_multi)):
             raise InputError('Error(' +
@@ -1071,9 +1148,6 @@ def main():
         # Convert all of this information to moltemplate (LT) format:
         genpoly.WriteLTFile(outfile)
 
-        # Now close the input file
-        if genpoly.settings.infile_name != '':  # <--if not reading from stdin
-            infile.close()
 
     except (ValueError, InputError) as err:
         sys.stderr.write('\n' + str(err) + '\n')
